# eric7.Plugins.VcsPlugins.vcsMercurial.StripExtension.HgStripDialog

Module implementing a dialog to enter the data to strip changesets.

### Global Attributes

None

### Classes

HgStripDialog | Class implementing a dialog to enter the data to strip changesets.

### Functions

None

## HgStripDialog

Class implementing a dialog to enter the data to strip changesets.

### Derived from

QDialog, Ui_HgStripDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgStripDialog | Constructor
__getRevision | Private method to generate the revision.
__updateOK | Private slot to update the OK button.
getData | Public method to retrieve the data for the strip action.

### Static Methods

None

#### HgStripDialog (Constructor)

HgStripDialog(tagsList, branchesList, bookmarksList=None, rev="", parent=None)

Constructor

tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
bookmarksList (list of str)
  list of bookmarks
rev (str)
  revision to strip from
parent (QWidget)
  reference to the parent widget

#### HgStripDialog.__getRevision

__getRevision()

Private method to generate the revision.

Return:
  revision

Return Type:
  str

#### HgStripDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgStripDialog.getData

getData()

Public method to retrieve the data for the strip action.

Return:
  tuple with the revision, a bookmark name, a flag indicating to enforce the strip action, a flag indicating to omit the creation of backup bundles and a flag indicating to not modify the working directory

Return Type:
  tuple (str, str, bool, bool, bool)

Up